Stan Math Library: stan/math/prim/mat/fun/mdivide_right_tri_low.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_right_tri_low.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MDIVIDE_RIGHT_TRI_LOW_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MDIVIDE_RIGHT_TRI_LOW_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stan/math/prim/mat/fun/mdivide_right_tri.hpp>
7 #include <stan/math/prim/mat/fun/promote_common.hpp>
8
9 namespace stan {
10 namespace math {
11
21 template <typename T1, typename T2, int R1, int C1, int R2, int C2>
22 inline
23 Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type,
24 R1, C2>
25 mdivide_right_tri_low(const Eigen::Matrix<T1, R1, C1> &b,
26 const Eigen::Matrix<T2, R2, C2> &A) {
27 return mdivide_right_tri<Eigen::Lower>
28 (promote_common<Eigen::Matrix<T1, R1, C1>,
29 Eigen::Matrix<T2, R1, C1> >(b),
30 promote_common<Eigen::Matrix<T1, R2, C2>,
31 Eigen::Matrix<T2, R2, C2> >(A));
32 }
33
34 }
35 }
36 #endif
stan
Definition: log_sum_exp.hpp:8
promote_common.hpp
mdivide_right_tri.hpp
stan::math::promote_common
common_type< T1, T2 >::type promote_common(const F &u)
Definition: promote_common.hpp:14
Eigen.hpp
stan::math::mdivide_right_tri_low
Eigen::Matrix< fvar< T >, R1, C1 > mdivide_right_tri_low(const Eigen::Matrix< fvar< T >, R1, C1 > &A, const Eigen::Matrix< fvar< T >, R2, C2 > &b)
Definition: mdivide_right_tri_low.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.